Version 0.7.0 — Version 0.9.0.dev0

# Version 0.7.0

## Changelog

### Maintenance

- Ensure that `imblearn.pipeline.Pipeline` is working when `memory` is activated and `joblib==0.11`. #687 by Christos Aridas.

- Refactor common test to use the dev tools from `scikit-learn` 0.23. #710 by Guillaume Lemaitre.

- Remove `FutureWarning` issued by `scikit-learn` 0.23. #710 by Guillaume Lemaitre.

- Impose keywords only argument as in `scikit-learn`. #721 by Guillaume Lemaitre.

### Changed models

The following models might give some different results due to changes:

- `imblearn.ensemble.BalancedRandomForestClassifier`

### Bug fixes

- Change the default value `min_samples_leaf` to be consistent with scikit-learn. #711 by zerolfx.

- Fix a bug due to change in `scikit-learn` 0.23 in `imblearn.metrics.make_index_balanced_accuracy`. The function was unusable. #710 by Guillaume Lemaitre.

- Raise a proper error message when only numerical or categorical features are given in `imblearn.over_sampling.SMOTENC`. #720 by Guillaume Lemaitre.

- Fix a bug when the median of the standard deviation is null in `imblearn.over_sampling.SMOTENC`. #675 by bganglia.

### Enhancements

- The classifier implemented in imbalanced-learn, `imblearn.ensemble.BalancedBaggingClassifier`, `imblearn.ensemble.BalancedRandomForestClassifier`, `imblearn.ensemble.EasyEnsembleClassifier`, and `imblearn.ensemble.RUSBoostClassifier`, accept `sampling_strategy` with the same key than in `y` without the need of encoding `y` in advance. #718 by Guillaume Lemaitre.

- Lazy import `keras` module when importing `imblearn.keras` #719 by Guillaume Lemaitre.

### Deprecation

- Deprecation of the parameters `n_jobs` in `imblearn.under_sampling.ClusterCentroids` since it was used by `sklearn.cluster.KMeans` which deprecated it. #710 by Guillaume Lemaitre.

- Deprecation of passing keyword argument by position similarly to `scikit-learn`. #721 by Guillaume lemaitre.